@@ -3,6 +3,7 @@ package fluentd
 import (
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
+	"k8s.io/apimachinery/pkg/util/sets"
 
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1alpha1"
 	test "github.com/openshift/cluster-logging-operator/test"
@@ -15,7 +16,7 @@ var _ = Describe("Generating fluentd config", func() {
 	)
 	BeforeEach(func() {
 		var err error
-		generator, err = NewConfigGenerator(false, false)
+		generator, err = NewConfigGenerator(true, true, true)
 		Expect(err).To(BeNil())
 		Expect(generator).ToNot(BeNil())
 		forwarding = &logging.ForwardingSpec{
@@ -54,17 +55,17 @@ var _ = Describe("Generating fluentd config", func() {
 				},
 			},
 			Pipelines: []logging.PipelineSpec{
-				logging.PipelineSpec{
+				{
 					Name:       "infra-pipeline",
 					SourceType: logging.LogSourceTypeInfra,
 					OutputRefs: []string{"infra-es"},
 				},
-				logging.PipelineSpec{
+				{
 					Name:       "apps-pipeline",
 					SourceType: logging.LogSourceTypeApp,
 					OutputRefs: []string{"apps-es-1", "apps-es-2"},
 				},
-				logging.PipelineSpec{
+				{
 					Name:       "audit-pipeline",
 					SourceType: logging.LogSourceTypeAudit,
 					OutputRefs: []string{"audit-es"},
@@ -73,6 +74,60 @@ var _ = Describe("Generating fluentd config", func() {
 		}
 	})
 
+	It("should generats container source config for given namespaces only", func() {
+		forwarding = &logging.ForwardingSpec{
+			Outputs: []logging.OutputSpec{
+				{
+					Type:     logging.OutputTypeElasticsearch,
+					Name:     "apps-es-1",
+					Endpoint: "es.svc.messaging.cluster.local:9654",
+					Secret: &logging.OutputSecretSpec{
+						Name: "my-es-secret",
+					},
+				},
+			},
+			Pipelines: []logging.PipelineSpec{
+				{
+					Name:       "apps-pipeline",
+					SourceType: logging.LogSourceTypeApp,
+					OutputRefs: []string{"apps-es-1", "apps-es-2"},
+					Namespaces: []string{"project1-namespace", "project2-namespace"},
+				},
+			},
+		}
+		results, err := generator.generateSource(sets.NewString(string(forwarding.Pipelines[0].SourceType)), sets.NewString(forwarding.Pipelines[0].Namespaces...))
+		Expect(err).To(BeNil())
+		test.Expect(results[0]).ToEqual(`
+# container logs
+<source>
+  @type tail
+  @id container-input
+  path "/var/log/containers/*_project1-namespace_*.log", "/var/log/containers/*_project2-namespace_*.log"
+  exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
+  pos_file "/var/log/es-containers.log.pos"
+  refresh_interval 5
+  rotate_wait 5
+  tag kubernetes.*
+  read_from_head "true"
+  @label @CONCAT
+  <parse>
+    @type multi_format
+    <pattern>
+      format json
+      time_format '%Y-%m-%dT%H:%M:%S.%N%Z'
+      keep_time_key true
+    </pattern>
+    <pattern>
+      format regexp
+      expression /^(?<time>.+) (?<stream>stdout|stderr)( (?<logtag>.))? (?<log>.*)$/
+      time_format '%Y-%m-%dT%H:%M:%S.%N%:z'
+      keep_time_key true
+    </pattern>
+  </parse>
+</source>
+		`)
+	})
+
 	It("should exclude source to pipeline labels when there are no pipelines for a given sourceType (e.g. only logs.app)", func() {
 		forwarding = &logging.ForwardingSpec{
 			Outputs: []logging.OutputSpec{
@@ -83,7 +138,7 @@ var _ = Describe("Generating fluentd config", func() {
 				},
 			},
 			Pipelines: []logging.PipelineSpec{
-				logging.PipelineSpec{
+				{
 					Name:       "apps-pipeline",
 					SourceType: logging.LogSourceTypeApp,
 					OutputRefs: []string{"secureforward-receiver"},
@@ -293,6 +348,7 @@ var _ = Describe("Generating fluentd config", func() {
 				</filter>
 				<filter **>
 					@type viaq_data_model
+					elasticsearch_index_prefix_field 'viaq_index_name'
 					default_keep_fields CEE,time,@timestamp,aushape,ci_job,collectd,docker,fedora-ci,file,foreman,geoip,hostname,ipaddr4,ipaddr6,kubernetes,level,message,namespace_name,namespace_uuid,offset,openstack,ovirt,pid,pipeline_metadata,rsyslog,service,systemd,tags,testcase,tlog,viaq_msg_id
 					extra_keep_fields "#{ENV['CDM_EXTRA_KEEP_FIELDS'] || ''}"
 					keep_empty_fields "#{ENV['CDM_KEEP_EMPTY_FIELDS'] || 'message'}"
@@ -336,17 +392,20 @@ var _ = Describe("Generating fluentd config", func() {
 					<elasticsearch_index_name>
 						enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
 						tag "journal.system** system.var.log** **_default_** **_kube-*_** **_openshift-*_** **_openshift_**"
-						name_type operations_full
-					</elasticsearch_index_name>
-					<elasticsearch_index_name>
+						name_type static
+						static_index_name infra-write
+						</elasticsearch_index_name>
+						<elasticsearch_index_name>
 						enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
 						tag "linux-audit.log** k8s-audit.log** openshift-audit.log**"
-						name_type audit_full
-					</elasticsearch_index_name>
-					<elasticsearch_index_name>
+						name_type static
+						static_index_name audit-write
+						</elasticsearch_index_name>
+						<elasticsearch_index_name>
 						enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
 						tag "**"
-						name_type project_full
+						name_type static
+						static_index_name app-write
 					</elasticsearch_index_name>
 				</filter>
 				<filter **>
@@ -355,6 +414,16 @@ var _ = Describe("Generating fluentd config", func() {
 					alt_key kubernetes.event.metadata.uid
 					alt_tags "#{ENV['GENID_ALT_TAG'] || 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'}"
 				</filter>
+				#flatten labels to prevent field explosion in ES
+				<filter ** >
+					@type record_transformer
+					enable_ruby true
+					<record>
+						kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+					</record>
+					remove_keys $.kubernetes.labels
+				</filter>
+			   
 
 				# Relabel specific source tags to specific intermediary labels for copy processing
 				<match kubernetes.**>
@@ -375,6 +444,14 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @APPS_PIPELINE
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SECUREFORWARD
+					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 
@@ -416,6 +493,20 @@ var _ = Describe("Generating fluentd config", func() {
 				</server>
 			</match>
 		</label>
+		<label @_LEGACY_SECUREFORWARD>
+			<match **>
+				@type copy
+				#include legacy secure-forward.conf
+				@include /etc/fluent/configs.d/secure-forward/secure-forward.conf
+			</match>
+		</label>
+		<label @_LEGACY_SYSLOG>
+			<match **>
+				@type copy
+				#include legacy Syslog
+				@include /etc/fluent/configs.d/syslog/syslog.conf
+			</match>
+		</label>
 	`)
 	})
 
@@ -688,6 +779,7 @@ var _ = Describe("Generating fluentd config", func() {
 				</filter>
 				<filter **>
 					@type viaq_data_model
+					elasticsearch_index_prefix_field 'viaq_index_name'
 					default_keep_fields CEE,time,@timestamp,aushape,ci_job,collectd,docker,fedora-ci,file,foreman,geoip,hostname,ipaddr4,ipaddr6,kubernetes,level,message,namespace_name,namespace_uuid,offset,openstack,ovirt,pid,pipeline_metadata,rsyslog,service,systemd,tags,testcase,tlog,viaq_msg_id
 					extra_keep_fields "#{ENV['CDM_EXTRA_KEEP_FIELDS'] || ''}"
 					keep_empty_fields "#{ENV['CDM_KEEP_EMPTY_FIELDS'] || 'message'}"
@@ -731,17 +823,20 @@ var _ = Describe("Generating fluentd config", func() {
 					<elasticsearch_index_name>
 						enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
 						tag "journal.system** system.var.log** **_default_** **_kube-*_** **_openshift-*_** **_openshift_**"
-						name_type operations_full
+						name_type static
+						static_index_name infra-write
 					</elasticsearch_index_name>
 					<elasticsearch_index_name>
 						enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
 						tag "linux-audit.log** k8s-audit.log** openshift-audit.log**"
-						name_type audit_full
+						name_type static
+						static_index_name audit-write
 					</elasticsearch_index_name>
 					<elasticsearch_index_name>
 						enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
 						tag "**"
-						name_type project_full
+						name_type static
+						static_index_name app-write
 					</elasticsearch_index_name>
 				</filter>
 				<filter **>
@@ -750,6 +845,15 @@ var _ = Describe("Generating fluentd config", func() {
 					alt_key kubernetes.event.metadata.uid
 					alt_tags "#{ENV['GENID_ALT_TAG'] || 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'}"
 				</filter>
+				#flatten labels to prevent field explosion in ES
+				<filter ** >
+					@type record_transformer
+					enable_ruby true
+					<record>
+						kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+					</record>
+					remove_keys $.kubernetes.labels
+				</filter>
 
 				# Relabel specific source tags to specific intermediary labels for copy processing
 				<match **_default_** **_kube-*_** **_openshift-*_** **_openshift_** journal.** system.var.log**>
@@ -767,6 +871,7 @@ var _ = Describe("Generating fluentd config", func() {
 				<match **>
 					@type stdout
 				</match>
+
 			</label>
 			
 			# Relabel specific sources (e.g. logs.apps) to multiple pipelines
@@ -777,6 +882,14 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @APPS_PIPELINE
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SECUREFORWARD
+					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 			<label @_LOGS_AUDIT>
@@ -786,6 +899,14 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @AUDIT_PIPELINE
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SECUREFORWARD
+					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 			<label @_LOGS_INFRA>
@@ -795,6 +916,14 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @INFRA_PIPELINE
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SECUREFORWARD
+					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 
@@ -840,6 +969,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id retry_infra_es
 						host es.svc.infra.cluster
 						port 9999
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -851,7 +981,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-infra-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-infra-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-infra-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -882,6 +1012,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id infra_es
 						host es.svc.infra.cluster
 						port 9999
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -893,7 +1024,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-infra-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-infra-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-infra-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						retry_tag retry_infra_es
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
@@ -927,6 +1058,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id retry_apps_es_1
 						host es.svc.messaging.cluster.local
 						port 9654
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -938,7 +1070,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -969,6 +1101,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id apps_es_1
 						host es.svc.messaging.cluster.local
 						port 9654
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -980,7 +1113,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						retry_tag retry_apps_es_1
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
@@ -1014,6 +1147,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id retry_apps_es_2
 						host es.svc.messaging.cluster.local2
 						port 9654
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -1025,7 +1159,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-other-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-other-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-other-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1056,6 +1190,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id apps_es_2
 						host es.svc.messaging.cluster.local2
 						port 9654
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -1067,7 +1202,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-other-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-other-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-other-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						retry_tag retry_apps_es_2
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
@@ -1101,6 +1236,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id retry_audit_es
 						host es.svc.audit.cluster
 						port 9654
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -1112,7 +1248,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-audit-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-audit-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-audit-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 						# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -1143,6 +1279,7 @@ var _ = Describe("Generating fluentd config", func() {
 						@id audit_es
 						host es.svc.audit.cluster
 						port 9654
+						verify_es_version_at_startup false
 						scheme https
 						ssl_version TLSv1_2
 						target_index_key viaq_index_name
@@ -1154,7 +1291,7 @@ var _ = Describe("Generating fluentd config", func() {
 						client_key '/var/run/ocp-collector/secrets/my-audit-secret/tls.key'
 						client_cert '/var/run/ocp-collector/secrets/my-audit-secret/tls.crt'
 						ca_file '/var/run/ocp-collector/secrets/my-audit-secret/ca-bundle.crt'
-						type_name com.redhat.viaq.common
+						type_name _doc
 						retry_tag retry_audit_es
 						write_operation create
 						reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
@@ -1180,6 +1317,21 @@ var _ = Describe("Generating fluentd config", func() {
 					</store>
 				</match>
 			</label>
+			<label @_LEGACY_SECUREFORWARD>
+				<match **>
+				  @type copy
+					#include legacy secure-forward.conf
+					@include /etc/fluent/configs.d/secure-forward/secure-forward.conf
+				</match>
+			</label>
+			<label @_LEGACY_SYSLOG>
+				<match **>
+					@type copy
+					#include legacy Syslog
+					@include /etc/fluent/configs.d/syslog/syslog.conf
+				</match>
+			</label>
 			`)
 	})
+
 })
