@@ -16,7 +16,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 	)
 	BeforeEach(func() {
 		var err error
-		generator, err = NewConfigGenerator(false, false)
+		generator, err = NewConfigGenerator(false, false, true)
 		Expect(err).To(BeNil())
 	})
 
@@ -71,6 +71,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			@id retry_oncluster_elasticsearch
 			host es.svc.messaging.cluster.local
 			port 9654
+            verify_es_version_at_startup false
 			scheme https
 			ssl_version TLSv1_2
 			target_index_key viaq_index_name
@@ -82,7 +83,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 			client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 			ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
-			type_name com.redhat.viaq.common
+			type_name _doc
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 			# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -113,6 +114,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			@id oncluster_elasticsearch
 			host es.svc.messaging.cluster.local
 			port 9654
+            verify_es_version_at_startup false
 			scheme https
 			ssl_version TLSv1_2
 			target_index_key viaq_index_name
@@ -124,7 +126,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			client_key '/var/run/ocp-collector/secrets/my-es-secret/tls.key'
 			client_cert '/var/run/ocp-collector/secrets/my-es-secret/tls.crt'
 			ca_file '/var/run/ocp-collector/secrets/my-es-secret/ca-bundle.crt'
-			type_name com.redhat.viaq.common
+			type_name _doc
 			retry_tag retry_oncluster_elasticsearch
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
@@ -175,6 +177,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			@id retry_other_elasticsearch
 			host es.svc.messaging.cluster.local
 			port 9654
+            verify_es_version_at_startup false
 			scheme http
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
@@ -182,7 +185,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			user fluentd
 			password changeme
 
-			type_name com.redhat.viaq.common
+			type_name _doc
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
 			# https://github.com/uken/fluent-plugin-elasticsearch#reload-after
@@ -213,6 +216,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			@id other_elasticsearch
 			host es.svc.messaging.cluster.local
 			port 9654
+            verify_es_version_at_startup false
 			scheme http
 			target_index_key viaq_index_name
 			id_key viaq_msg_id
@@ -220,7 +224,7 @@ var _ = Describe("Generating fluentd config blocks", func() {
 			user fluentd
 			password changeme
 
-			type_name com.redhat.viaq.common
+			type_name _doc
 			retry_tag retry_other_elasticsearch
 			write_operation create
 			reload_connections "#{ENV['ES_RELOAD_CONNECTIONS'] || 'true'}"
