@@ -39,8 +39,8 @@ func TestNewFluentdPodSpecWhenFieldsAreUndefined(t *testing.T) {
 }
 
 func TestNewFluentdPodSpecWhenResourcesAreDefined(t *testing.T) {
-	limitMemory := resource.MustParse("100Gi")
-	requestMemory := resource.MustParse("120Gi")
+	limitMemory := resource.MustParse("120Gi")
+	requestMemory := resource.MustParse("100Gi")
 	requestCPU := resource.MustParse("500m")
 	cluster := &logging.ClusterLogging{
 		Spec: logging.ClusterLoggingSpec{
@@ -48,7 +48,7 @@ func TestNewFluentdPodSpecWhenResourcesAreDefined(t *testing.T) {
 				Logs: logging.LogCollectionSpec{
 					Type: "fluentd",
 					FluentdSpec: logging.FluentdSpec{
-						Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
+						Resources: newResourceRequirements("120Gi", "", "100Gi", "500m"),
 					},
 				},
 			},
@@ -75,12 +75,12 @@ func TestNewFluentdPodSpecWhenResourcesAreDefined(t *testing.T) {
 func TestFluentdPodSpecHasTaintTolerations(t *testing.T) {
 
 	expectedTolerations := []v1.Toleration{
-		v1.Toleration{
+		{
 			Key:      "node-role.kubernetes.io/master",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
 		},
-		v1.Toleration{
+		{
 			Key:      "node.kubernetes.io/disk-pressure",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
@@ -128,12 +128,12 @@ func TestNewFluentdPodSpecWhenSelectorIsDefined(t *testing.T) {
 
 func TestNewFluentdPodNoTolerations(t *testing.T) {
 	expTolerations := []v1.Toleration{
-		v1.Toleration{
+		{
 			Key:      "node-role.kubernetes.io/master",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
 		},
-		v1.Toleration{
+		{
 			Key:      "node.kubernetes.io/disk-pressure",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
@@ -169,12 +169,12 @@ func TestNewFluentdPodWithTolerations(t *testing.T) {
 
 	expTolerations := []v1.Toleration{
 		providedToleration,
-		v1.Toleration{
+		{
 			Key:      "node-role.kubernetes.io/master",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
 		},
-		v1.Toleration{
+		{
 			Key:      "node.kubernetes.io/disk-pressure",
 			Operator: v1.TolerationOpExists,
 			Effect:   v1.TaintEffectNoSchedule,
@@ -252,6 +252,53 @@ func TestNewFluentdPodSpecWhenProxyConfigExists(t *testing.T) {
 	checkFluentdProxyVolumesAndVolumeMounts(t, podSpec, constants.FluentdTrustedCAName)
 }
 
+func TestFluentdPodInitContainerWithDefaultForwarding(t *testing.T) {
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			Collection: &logging.CollectionSpec{
+				Logs: logging.LogCollectionSpec{
+					Type:        "fluentd",
+					FluentdSpec: logging.FluentdSpec{},
+				},
+			},
+			LogStore: &logging.LogStoreSpec{
+				Type: "elasticsearch",
+			},
+		},
+	}
+
+	forwardingSpec := logforward.ForwardingSpec{}
+
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, forwardingSpec)
+
+	if len(podSpec.InitContainers) == 0 {
+		t.Error("Expected pod to have defined init container")
+	}
+}
+
+func TestFluentdPodNoInitContainerWithOutDefaultForwarding(t *testing.T) {
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			Collection: &logging.CollectionSpec{
+				Logs: logging.LogCollectionSpec{
+					Type:        "fluentd",
+					FluentdSpec: logging.FluentdSpec{},
+				},
+			},
+		},
+	}
+
+	forwardingSpec := logforward.ForwardingSpec{
+		DisableDefaultForwarding: true,
+	}
+
+	podSpec := newFluentdPodSpec(cluster, "test-app-name", "test-infra-name", nil, nil, forwardingSpec)
+
+	if len(podSpec.InitContainers) > 0 {
+		t.Error("Expected pod to have no init containers")
+	}
+}
+
 func checkFluentdProxyEnvVar(t *testing.T, podSpec v1.PodSpec, name string, value string) {
 	env := podSpec.Containers[0].Env
 	found := false
