@@ -24,10 +24,13 @@ const (
 
 	//ForwardingAnnotation  Annotate CL instance with a value of "enabled"
 	ForwardingAnnotation = "clusterlogging.openshift.io/logforwardingtechpreview"
+
+	// UseOldRemoteSyslogPlugin Annotation in LogFprwarding to use old plugin (docebo/fluent-plugin-remote-syslog) to send syslog
+	UseOldRemoteSyslogPlugin = "clusterlogging.openshift.io/useoldremotesyslogplugin"
 )
 
 var (
-	outputTypes = sets.NewString(string(logforward.OutputTypeElasticsearch), string(logforward.OutputTypeForward))
+	outputTypes = sets.NewString(string(logforward.OutputTypeElasticsearch), string(logforward.OutputTypeForward), string(logforward.OutputTypeSyslog))
 	sourceTypes = sets.NewString(string(logforward.LogSourceTypeApp), string(logforward.LogSourceTypeInfra), string(logforward.LogSourceTypeAudit))
 )
 
@@ -40,6 +43,11 @@ func isForwardingEnabled(cluster *logging.ClusterLogging) bool {
 
 func (clusterRequest *ClusterLoggingRequest) generateCollectorConfig() (config string, err error) {
 
+	if clusterRequest.cluster == nil || clusterRequest.cluster.Spec.Collection == nil {
+		logger.Warnf("skipping collection config generation as 'collection' section is not specified in the CLO's CR")
+		return "", nil
+	}
+
 	switch clusterRequest.cluster.Spec.Collection.Logs.Type {
 	case logging.LogCollectionTypeFluentd:
 		break
@@ -48,35 +56,33 @@ func (clusterRequest *ClusterLoggingRequest) generateCollectorConfig() (config s
 	}
 
 	clusterRequest.ForwardingSpec = clusterRequest.normalizeLogForwarding(clusterRequest.cluster.Namespace, clusterRequest.cluster)
-
 	generator, err := forwarding.NewConfigGenerator(
 		clusterRequest.cluster.Spec.Collection.Logs.Type,
 		clusterRequest.includeLegacyForwardConfig(),
 		clusterRequest.includeLegacySyslogConfig(),
-	)
-
+		clusterRequest.useOldRemoteSyslogPlugin())
 	if err != nil {
 		logger.Warnf("Unable to create collector config generator: %v", err)
-		return "", clusterRequest.UpdateCondition(
-			logging.CollectorDeadEnd,
-			"Unable to generate collector configuration",
-			"No defined logstore destination",
-			v1.ConditionTrue,
-		)
+		return "",
+			clusterRequest.UpdateCondition(
+				logging.CollectorDeadEnd,
+				"Unable to generate collector configuration",
+				"No defined logstore destination",
+				v1.ConditionTrue,
+			)
 	}
-
 	generatedConfig, err := generator.Generate(&clusterRequest.ForwardingSpec)
-
 	if err != nil {
-		logger.Warnf("Unable to create collector config generator: %v", err)
-		return "", clusterRequest.UpdateCondition(
-			logging.CollectorDeadEnd,
-			"Collectors are defined but there is no defined LogStore of LogForward destinations",
-			"No defined logstore destination",
-			v1.ConditionTrue,
-		)
+		logger.Warnf("Unable to generate log confguraiton: %v", err)
+		return "",
+			clusterRequest.UpdateCondition(
+				logging.CollectorDeadEnd,
+				"Collectors are defined but there is no defined LogStore or LogForward destinations",
+				"No defined logstore destination",
+				v1.ConditionTrue,
+			)
 	}
-
+	// else
 	err = clusterRequest.UpdateCondition(
 		logging.CollectorDeadEnd,
 		"",
@@ -88,9 +94,9 @@ func (clusterRequest *ClusterLoggingRequest) generateCollectorConfig() (config s
 }
 
 func (clusterRequest *ClusterLoggingRequest) normalizeLogForwarding(namespace string, cluster *logging.ClusterLogging) logforward.ForwardingSpec {
-	logger.Debugf("Normalizing logforwarding from request: %v", clusterRequest)
-	logger.Debugf("ForwardingRequest: %v", clusterRequest.ForwardingRequest)
-	logger.Debugf("ForwardingSpec: %v", clusterRequest.ForwardingSpec)
+	logger.DebugObject("Normalizing logforwarding from request: %v", clusterRequest)
+	logger.DebugObject("ForwardingRequest: %v", clusterRequest.ForwardingRequest)
+	logger.DebugObject("ForwardingSpec: %v", clusterRequest.ForwardingSpec)
 	if cluster.Spec.LogStore != nil && cluster.Spec.LogStore.Type == logging.LogStoreTypeElasticsearch {
 		if !clusterRequest.ForwardingSpec.DisableDefaultForwarding && len(clusterRequest.ForwardingSpec.Pipelines) == 0 {
 			logger.Debug("Configuring logforwarding to utilize the operator managed logstore")
@@ -116,7 +122,7 @@ func (clusterRequest *ClusterLoggingRequest) normalizeLogForwarding(namespace st
 			}
 			return logforward.ForwardingSpec{
 				Outputs: []logforward.OutputSpec{
-					logforward.OutputSpec{
+					{
 						Name:     internalOutputName,
 						Type:     logforward.OutputTypeElasticsearch,
 						Endpoint: constants.LogStoreService,
@@ -126,12 +132,12 @@ func (clusterRequest *ClusterLoggingRequest) normalizeLogForwarding(namespace st
 					},
 				},
 				Pipelines: []logforward.PipelineSpec{
-					logforward.PipelineSpec{
+					{
 						Name:       defaultAppPipelineName,
 						SourceType: logforward.LogSourceTypeApp,
 						OutputRefs: []string{internalOutputName},
 					},
-					logforward.PipelineSpec{
+					{
 						Name:       defaultInfraPipelineName,
 						SourceType: logforward.LogSourceTypeInfra,
 						OutputRefs: []string{internalOutputName},
@@ -205,6 +211,8 @@ func (clusterRequest *ClusterLoggingRequest) normalizeLogForwarding(namespace st
 	}
 	clusterRequest.ForwardingRequest.Status.LogSources = logSources.List()
 
+	normalized.DisableDefaultForwarding = clusterRequest.ForwardingSpec.DisableDefaultForwarding
+
 	return normalized
 }
 
